@@ -1446,3 +1446,29 @@ class VariableClUpdateBinhostTimeout(Variable):
     """
     type = "int"
     value = "5"
+
+class VariableClUpdateCheckRepSet(Variable):
+    """
+    Удлять лишние файлы из репозиториев (например созданные пользователем)
+    """
+    type = "bool"
+    value = "off"
+
+    opt = ["--check-repos", "-C"]
+
+    def init(self):
+        self.label = _("Check the repositories integrity")
+        self.help = _("check and fix the repositories integrity")
+
+class VariableClUpdateOnedepthSet(Variable):
+    """
+    Удлять лишние файлы из репозиториев (например созданные пользователем)
+    """
+    type = "bool"
+    value = "off"
+
+    opt = ["--one-depth", "-1"]
+
+    def init(self):
+        self.label = _("Clear the history of repositories")
+        self.help = _("clear the history of repositories")
